# Terms & Conditions

## TopoBank

TopoBank are database and data processing services (in the following referred to as the "Services") operated by the Simulation Group at the University of Freiburg (in the following referred to as the "Simulation Group") and made available free of charge to the scientific community. By using the Services, you agree to be bound by these Terms & Conditions. If you are using the Services on behalf of an organization, you are agreeing to these Terms & Conditions for that organization and promising that you have the authority to bind that organization to these Terms & Conditions. In that case, “you” and “your” will refer to that organization.

## Our Services are provided “AS-IS”

We can’t promise that all parts of the Services will be free from errors and bugs or secure at all times. As such, the Services are provided “as is” and “as available”, at your own risk, without any express, implied, statutory or other warranty or condition of any kind. Without limiting the foregoing, we disclaim any warranties of merchantability, fitness for a particular purpose, freedom from errors and non-infringement. Neither the Simulation Group nor its affiliates will have any responsibility for any harm to your computer system, loss or corruption of data, or other harm that results from your access to or use of the Services.

While the service is provided "AS-IS" without guarantee of fitness for a particular purpose, we practice fullest transparency as to the operation of the Services. As such, the underlying software framework is made available for inspection to interested third-parties under the MIT license. If errors are brought to our attention, we will try to correct them. The respective code bases can be found at:

* [https://github.com/IMTEK-Simulation/TopoBank](https://github.com/IMTEK-Simulation/TopoBank)
* [https://github.com/IMTEK-Simulation/PyCo](https://github.com/IMTEK-Simulation/PyCo)

## Limitation of liability

The Simulation Group accepts no responsibility or liability whatsoever with regard to the information on this site. This disclaimer is not intended to limit the liability of the Simulation Group in contravention of any requirements laid down in applicable national law nor to exclude its liability for matters which may not be excluded under that law.

## Privacy policy

By using our Services, you may provide us with information and files (your data). You retain full ownership to your data. We don’t claim any ownership to it. These Terms & Conditions do not grant us any rights to your data or intellectual property except for the limited rights that are needed to run the Services, as explained below.

By using our Services, you give us permission to host your data and process it as necessary for the operation of our Services. Results of this processing includes features visible to you, for example, previews of topography maps or analysis results. It also includes design choices we make to technically administer our Services, for example, how we redundantly backup data to keep it safe. This permission also extends to our affiliates and trusted third parties we work with to provide the Services. To be clear, no matter how the Services change, we won’t share your content with others for any purpose unless you direct us to.

The Services provide features that allow you to share your data with others or to make it public under a license of your choice. We will not have any responsibility arising from the sharing of your data.

In order to ensure scientific accountability, all data uploaded to our Services will be permanently linked to your ORCID (https://orcid.org), a unique personal identifier that is designed to identify you as a researcher. Obtaining an ORCID is a necessary prerequisite for using our Services. Any data that you share with others or that you make public will be linked to your ORCID and can hence be traced back to you.

When logging into our site we ask you to authenticate our Services with ORCID. We will request and store the following information from ORCID: Your full name and your e-mail address. By using our Services, you give permission to use your email address to contact you about important changes to our Services (such as changes to these Terms & Conditions) or to inform about incidents.

## Change to these Terms & Conditions

We may revise these Terms & Conditions from time to time and the most current version will always be posted on our website. If a revision, in our sole discretion, is material we will notify you (for example via email to the email address associated with your ORCID). By continuing to access or use the Services after revisions become effective, you agree to be bound by the revised Terms & Conditions. If you do not agree to the new Terms & Conditions, please stop using the Services.

### Contact information

The Simulation Group is represented by:

Prof. Lars Pastewka   
Department of Microsystems Engineering (IMTEK)  
University of Freiburg  
Georges-Köhler-Alle 103
79110 Freiburg  
Germany
